#NationalAnalysis.R
#2019_04_19: Modifies the previous script to run on laptop. Chiefly folder name changes. Secondly changing plots. 
#2019_04_18: This script modifies the one last saved on 2018_10_05.  It adds the Diebold-Mariano test and changes the Clark Forecast Horizons in the table from c(12,24,60,120) to c(3,6,12,24) 
#2019_05_02:  Added TIFF file support for submission to Journal of Macroeconomics. Removed superfluous code. 

BeginRunning <- Sys.time()
filefolder <- paste("C:/Users/JTS3/Desktop/CityArticle/CPInational/",gsub(" ","_",gsub(":","",gsub("-","",BeginRunning))),"/",sep="" )
if(!dir.exists(filefolder) ){dir.create(filefolder)}

library(dynlm)
library(Hmisc)
library(forecast) 


stars <- function(input){symnum(input, corr = FALSE, cutpoints = c(0,.001,.01,.05, .1, 1), symbols = c("***","**","*","."," "))}

NATL <- read.csv("C:/Users/JTS3/Desktop/CityArticle/CPInational/UrbanPhillipsNationalSection.csv",stringsAsFactors=FALSE)


for(i in c("SA0L12E","CPILFESL")){
	tempvar <- eval(parse(text=paste("NATL$",i,sep="")))
	plot(I(NATL$CPIAUCSL- tempvar) ~ NATL$UNRATE ,type='l')
	text(I(NATL$CPIAUCSL- tempvar) ~ NATL$UNRATE , labels=round(NATL$MetricYear,0))#, subset=NATL$MetricYear>=1976 & NATL$MetricYear<1981 )
	fit <- lm(I(NATL$CPIAUCSL-tempvar) ~ NATL$UNRATE)
	abline(fit,col='red',lwd=2)
	print(i)
	print(summary(fit))
	#readline("next?")
}





fname <- paste(filefolder,"CPIplot.png")
png(fname)
par(mar=c(2.6,2.6,.5,.75), mgp=c(1.6,.6,0))  #This command makes the margins smaller
plot(NATL$SA0L12E ~ NATL$MetricYear, type='l', ylim=c(-2,15), ylab="CPI year-on-year growth rate", xlab="year")
lines(NATL$CPILFESL ~ NATL$MetricYear, col='red')
lines(NATL$CPIAUCSL ~ NATL$MetricYear, col='green')
legend('topright', legend=c("all items","less food & fuel","less food,fuel, & shelter"), col=c("green","red","black"), lty=c(1,1,1) )
dev.off()


nrows <- length(NATL$SA0L12E)
NATL$SA0L12E_sd <- rep(NA, nrows)
NATL$CPILFESL_sd <- rep(NA, nrows)
NATL$CPIAUCSL_sd <- rep(NA, nrows)
for(i in c(1:(nrows)) ){
j <- 15#one half of the period
NATL$SA0L12E_sd[i+j] <- sd(NATL$SA0L12E[i:(i+j*2)])
NATL$CPILFESL_sd[i+j] <- sd(NATL$CPILFESL[i:(i+j*2)])
NATL$CPIAUCSL_sd[i+j] <- sd(NATL$CPIAUCSL[i:(i+j*2)])
}


fname <- paste(filefolder,"CPIplotSD.png")
png(fname)
par(mar=c(2.6,2.6,.5,.75), mgp=c(1.6,.6,0))  #This command makes the margins smaller
plot(NATL$SA0L12E_sd ~ NATL$MetricYear, type='l', ylab=paste(j*2,"month 2 sided Rolling Standard Deviation"), xlab="year")
lines(NATL$CPILFESL_sd ~ NATL$MetricYear, col='red')
lines(NATL$CPIAUCSL_sd ~ NATL$MetricYear, col='green')
legend('topright', legend=c("all items","less food & fuel","less food,fuel,& shelter"), col=c("green","red","black"), lty=c(1,1,1) )
dev.off()

# This shows that all items CPI has a larger standard deviation in the recent period.
	# Excising food and fuel reduces most of the variation.
	# Further excising shelter reduces variation in the early 1980s but little elsewhere. 
	# SA0L12E has comparable volatility when compared to CPIFESL. 






for(fnameformat in c("CPIplot_combo.png","CPIplot_combo.tiff")){
fname <- paste(filefolder,fnameformat)
if(fnameformat=="CPIplot_combo.png" ){ png(fname, width = 750)}
if(fnameformat=="CPIplot_combo.tiff"){tiff(fname, width = 750)}
par(mar=c(2.6,2.6,.5,.75), mgp=c(1.6,.6,0), mfrow=c(2,1))  #This command makes the margins smaller
 plot(NATL$SA0L12E  ~ NATL$MetricYear, type='l', ylim=c(-2,15), ylab="CPI year-on-year growth rate", xlab="",lwd=2, lty=2)
lines(NATL$CPILFESL ~ NATL$MetricYear, col='grey' , lwd=2)
lines(NATL$CPIAUCSL ~ NATL$MetricYear, col='black', lwd=2)
legend('topright', legend=c("all items","less food & fuel","less food,fuel, & shelter"), col=c("black","grey","black"), lty=c(1,1,1) ,lwd=c(2,2,2))
plot(NATL$SA0L12E_sd ~ NATL$MetricYear, type='l', ylab=paste(j*2,"month 2 sided Rolling StDev"), xlab="year",lwd=2,lty=2)
lines(NATL$CPILFESL_sd ~ NATL$MetricYear, col='grey', lwd=2)
lines(NATL$CPIAUCSL_sd ~ NATL$MetricYear, col='black', lwd=2)
#legend('topright', legend=c("all items","less food & fuel","less food,fuel,& shelter"), col=c("green","red","black"), lty=c(1,1,1) )
dev.off()
}























#Now lets treat everything like an R time series object
SA0L12E_full  <- ts(NATL$SA0L12E  , frequency=12, start=c(1968,1) ) 
CPIAUCSL_full <- ts(NATL$CPIAUCSL , frequency=12, start=c(1968,1) )  
CPILFESL_full <- ts(NATL$CPILFESL , frequency=12, start=c(1968,1) )  
UNRATE_full   <- ts(NATL$UNRATE   , frequency=12, start=c(1968,1) )
SAH1_full     <- ts(NATL$SAH1     , frequency=12, start=c(1968,1) )

tempdf <- expand.grid(core=c("SA0L12E","CPILFESL"),timestart=c(1968,1985),timeend=c(2000,2018),horizon=c(3,6,12,24), stringsAsFactors=FALSE)
for(i in c(1:dim(tempdf)[1])){
	#Define the variables and the windows
	SA0L12E <-  window(  SA0L12E_full  , start=c(tempdf$timestart[i],1), end=c(tempdf$timeend[i],1) )
	CPIAUCSL <- window(  CPIAUCSL_full , start=c(tempdf$timestart[i],1), end=c(tempdf$timeend[i],1) )
	CPILFESL <- window(  CPILFESL_full , start=c(tempdf$timestart[i],1), end=c(tempdf$timeend[i],1) )
	UNRATE   <- window(  UNRATE_full   , start=c(tempdf$timestart[i],1), end=c(tempdf$timeend[i],1) )
	fit <- dynlm( I(lag(CPIAUCSL,k=tempdf$horizon[i]) - CPIAUCSL) ~ I(eval(parse(text=tempdf$core[i]))-CPIAUCSL) )
	tempdf$rsquared[i] <- summary(fit)$r.squared
	tempdf$coeff[i] <- summary(fit)$coefficients["I(eval(parse(text = tempdf$core[i])) - CPIAUCSL)","Estimate"]
	tempdf$se[i] <- summary(fit)$coefficients["I(eval(parse(text = tempdf$core[i])) - CPIAUCSL)",2]
	tempdf$pval[i] <- summary(fit)$coefficients["I(eval(parse(text = tempdf$core[i])) - CPIAUCSL)",4]
	#plot the oncoming change in CPI and the deviation of core from CPI
	fname <- paste(filefolder,"CLARKforecast",tempdf$core[i],tempdf$timestart[i],tempdf$timeend[i],tempdf$horizon[i],".png",sep="")
	png(fname)
	plot(I(lag(CPIAUCSL,k=tempdf$horizon[i]) - CPIAUCSL), col='black', main=tempdf$core[i] , ylab="change in inflation, core minus all items") 
	lines(I(eval(parse(text=tempdf$core[i]))-CPIAUCSL), col='red')
	legend('topleft',legend=c(paste(tempdf$horizon[i]," month change in inflation",sep=""),"deviation of core from CPI"),col=c('black','red'),lty=c(1,1))
	dev.off()
}
	tempdf2 <- as.data.frame(cbind(tempdf$rsquared[seq(1,31,2)],tempdf$rsquared[seq(2,32,2)],tempdf$horizon[seq(2,32,2)],tempdf$timestart[seq(2,32,2)],tempdf$timeend[seq(2,32,2)]))
	colnames(tempdf2) <- c("SA0L12E","CPILFESL","horizon","start","end")
	tempdf2$thing <- paste(tempdf2$start,"-",tempdf2$end,sep="")
	tempdf2$color <- tempdf2$horizon/12
	tempdf2$color[tempdf2$color==5] <- 3
	tempdf2$color[tempdf2$color==10] <- 4
		fname <- paste(filefolder,"CLARKforecastTABLErsq.png",sep="")
		png(fname)
		plot(-1000,ylim=c(0,1),xlim=c(0,1), ylab="CPILFESL r^2",xlab="SA0L12E r^2")
		text(tempdf2[,2] ~ tempdf2[,1],labels=tempdf2[,6],col=tempdf2[,7])
		abline(0,1,lty=2)
		legend('bottomright',legend=c("3","6","12","24"),pch=c(16,16,16,16),col=c(1,2,3,4))
		dev.off()
		#	plot(-1000 ,ylab="CPILFESL",xlab="SA0L12E",ylim=c(-2,0.1),xlim=c(-2.8,0.1))
		#	text(log(tempdf2[,2],10) ~ log(tempdf2[,1],10),labels=tempdf2[,6],col=tempdf2[,7])
		#	abline(0,1,lty=2)
		#	legend('bottomright',legend=c("12","24","60","120"),pch=c(16,16,16,16),col=c(1,2,3,4))
tempdf <- tempdf[order(tempdf$core, tempdf$timestart),]
tempdf$pval <- stars(tempdf$pval)
tempdf$se <- paste("(",round(tempdf$se,3),")",sep="")
tempdf$coeff <- round(tempdf$coeff,3)
tempdf$rsquared <- round(tempdf$rsquared,3)

	latextemp <- latex(
		tempdf,
		file=paste(filefolder,"CLARKforecast.tex",sep=""),
		rowname=NULL,
		caption="Predicting the change in inflation with All items less Food Shelter and Energy (SA0L12E) versus All items less Food and Energy (CPILFESL). Comparison of core inflation measures ability to forecast oncoming changes in inflation. All estimates are made with the dynlm R package. ",
		caption.loc="bottom",
		caption.lot="Predicting the change in inflation with SA0L12E vs CPILFESL",
		colheads=FALSE,
		col.just=c("c","c","c","c","c","r","c","l"),
		cgroup=c("Core Measure", "Time Period","Horizon","$r^2$","coefficient"),
		n.cgroup = c(1,2,1,1,3),
		label="table:CLARKforecast"
		)








##RMSE table of out-of-sample forecasts

tempdf <- expand.grid(core=c("CPIAUCSL","SA0L12E","CPILFESL"),timestart=c(1968,1985),timeend=c(2000),horizon=c(1:120), stringsAsFactors=FALSE)
for(i in c(1:dim(tempdf)[1])){
	#Define the variables and the windows
	SA0L12E <-  window(  SA0L12E_full  , start=c(tempdf$timestart[i],1), end=c(tempdf$timeend[i],1) )
	CPIAUCSL <- window(  CPIAUCSL_full , start=c(tempdf$timestart[i],1), end=c(tempdf$timeend[i],1) )
	CPILFESL <- window(  CPILFESL_full , start=c(tempdf$timestart[i],1), end=c(tempdf$timeend[i],1) )
	UNRATE   <- window(  UNRATE_full   , start=c(tempdf$timestart[i],1), end=c(tempdf$timeend[i],1) )
	fit <- dynlm( CPIAUCSL ~    lag( eval(parse(text=tempdf$core[i])), k=-tempdf$horizon[i])       )
	tempdf$rsquared[i] <- summary(fit)$r.squared
	tempdf$coeff[i] <- summary(fit)$coefficients["lag(eval(parse(text = tempdf$core[i])), k = -tempdf$horizon[i])","Estimate"]
	tempdf$se[i] <- summary(fit)$coefficients["lag(eval(parse(text = tempdf$core[i])), k = -tempdf$horizon[i])",2]
	tempdf$pval[i] <- summary(fit)$coefficients["lag(eval(parse(text = tempdf$core[i])), k = -tempdf$horizon[i])",4]
	forecast <- fit$coeff["(Intercept)"] + fit$coeff["lag(eval(parse(text = tempdf$core[i])), k = -tempdf$horizon[i])"]*lag(window(eval(parse(text = paste(tempdf$core[i],"_full",sep=""))), start=c(2000,1), end=c(2018,6) ), k = -tempdf$horizon[i])
	tempdf$rmse[i] <- sqrt(mean((CPIAUCSL_full - forecast)^2))

	#now we need a Diebold Mariano test for core != "CPIAUCSL" !
	if(tempdf$core[i]=="CPIAUCSL"){ tempdf$DMpvalue[i] <- 1  } #Don't run the test, the comparison of CPIAUCSL to CPIAUCSL will not show evidence that it diverges
	else{
		fit_baseline <- dynlm( CPIAUCSL ~  lag( CPIAUCSL, k=-tempdf$horizon[i])  )
		forecast_baseline <- fit_baseline$coeff["(Intercept)"] + fit_baseline$coeff["lag(CPIAUCSL, k = -tempdf$horizon[i])"]*lag(window(CPIAUCSL, start=c(2000,1), end=c(2018,6) ), k = -tempdf$horizon[i])
		tempdf$DMpvalue[i] <- dm.test(e1=(CPIAUCSL_full-forecast), e2=(CPIAUCSL_full-forecast_baseline), alternative = "less", h = tempdf$horizon[i])$p.value[[1]]
		#For ‘alternative="less"’, the alternative hypothesis is that method 2 is less accurate than method 1.
		#That is to say that the "autocorrelation" model is worse than the core inflation model
	}

	plot(CPIAUCSL_full, col='black', main=tempdf$core[i] , ylab="inflation") 
	abline(v=2000,lty=2)
	lines( eval(parse(text=paste(tempdf$core[i],"_full",sep=""))), col='red',lty=2)
	lines(forecast,col='green')
}

fname  <- paste(filefolder,"RMSE.png")
png(fname)
plot(-1000,ylab="RMSE - Forecast of all items inflation 2000--2018", xlab="Horizon in Months",ylim=c(0,5),xlim=c(0,120),sub="black - trained on 1968-2000, red - trained on 1985-2000")
#points(tempdf$rmse ~ tempdf$horizon,subset=tempdf$timestart==1985,col='red')
points(tempdf$rmse ~ tempdf$horizon,subset=tempdf$core=="CPIAUCSL"&tempdf$timestart==1985,pch=16,col='red')
points(tempdf$rmse ~ tempdf$horizon,subset=tempdf$core=="CPIAUCSL"&tempdf$timestart==1968,pch=16,col='black')
points(tempdf$rmse ~ tempdf$horizon,subset=tempdf$core=="CPILFESL"&tempdf$timestart==1985,pch=1,col='red')
points(tempdf$rmse ~ tempdf$horizon,subset=tempdf$core=="CPILFESL"&tempdf$timestart==1968,pch=1,col='black')
points(tempdf$rmse ~ tempdf$horizon,subset=tempdf$core=="SA0L12E" &tempdf$timestart==1985,pch=4,col='red')
points(tempdf$rmse ~ tempdf$horizon,subset=tempdf$core=="SA0L12E" &tempdf$timestart==1968,pch=4,col='black')
abline(v=30,lty=3)
abline(v=70,lty=3)
abline(v=6,lty=3)
legend('bottomright',legend=c("CPIAUCSL","CPILFESL","SA0L12E"),pch=c(16,1,4))
dev.off()
	#There are three points where the core measures in these single lag models transition to best. 
	#From 30 months to 70 months, core measures have lower RMSE than the CPI all items models. 
	#From 6 months to 70 months, core models trained on data after 1985 have lower RMSE. 
	#Models trained on post-1968 data have much higher RMSE after the 70 month horizon because they are trained on high inflation data. 
	#The CPILFESL data does a better job of predicting medium run all items inflation when trained on post 1985 data. 
	#The SA0L12E  data does a better job of predicting medium run all items inflation when trained on post 1968 data. 



output <- data.frame(matrix(,nrow=3*2,ncol=10))
colnames(output) <- c("timestart","core","m3","m3dm","m6","m6dm","m12","m12dm","m24","m24dm")
output$timestart <- c(rep(1968,3),rep(1985,3))
output$core <- rep(c("CPIAUCSL","SA0L12E","CPILFESL"),2)
for(i in c(1:dim(output)[1]) ){
	output$m3[i] <- tempdf$rmse[ tempdf$timestart==output$timestart[i] & tempdf$core==output$core[i] & tempdf$horizon==3]
	output$m6[i] <- tempdf$rmse[ tempdf$timestart==output$timestart[i] & tempdf$core==output$core[i] & tempdf$horizon==6]
	output$m12[i] <- tempdf$rmse[ tempdf$timestart==output$timestart[i] & tempdf$core==output$core[i] & tempdf$horizon==12]
	output$m24[i] <- tempdf$rmse[ tempdf$timestart==output$timestart[i] & tempdf$core==output$core[i] & tempdf$horizon==24]
	#Grab the Diebold-Mariano tests
	output$m3dm[i] <- tempdf$DMpvalue[ tempdf$timestart==output$timestart[i] & tempdf$core==output$core[i] & tempdf$horizon==3]
	output$m6dm[i] <- tempdf$DMpvalue[ tempdf$timestart==output$timestart[i] & tempdf$core==output$core[i] & tempdf$horizon==6]
	output$m12dm[i] <- tempdf$DMpvalue[ tempdf$timestart==output$timestart[i] & tempdf$core==output$core[i] & tempdf$horizon==12]
	output$m24dm[i] <- tempdf$DMpvalue[ tempdf$timestart==output$timestart[i] & tempdf$core==output$core[i] & tempdf$horizon==24]
}
output$timestart <- paste(output$timestart,"--2000",sep="")
#relative root mean squared error
theseones <- c("m3","m6","m12","m24")
output[2,theseones] <- output[2,theseones]/output[1,theseones]
output[3,theseones] <- output[3,theseones]/output[1,theseones]
output[5,theseones] <- output[5,theseones]/output[4,theseones]
output[6,theseones] <- output[6,theseones]/output[4,theseones]

fname  <- paste(filefolder,"RelativeRMSE.png")
png(fname)
plot(-100,ylim=c(0,1.75),xlim=c(0,24), xlab="horizon in months",ylab="RMSE relative to model with a single lag of all items CPI")
lines(t(output[2,theseones]) ~ c(3,6,12,24), type='o', col='red',pch=17)
lines(t(output[3,theseones]) ~ c(3,6,12,24), type='o', col='red',pch=16)
lines(t(output[5,theseones]) ~ c(3,6,12,24), type='o', col='black',pch=17)
lines(t(output[6,theseones]) ~ c(3,6,12,24), type='o', col='black',pch=16)
legend('bottomright',legend=c("SA0L12E 1968","CPILFESL 1968","SA0L12E 1985","CPILFESL 1985"),lty=c(1,1,1,1),col=c('red','red','black','black'),pch=c(17,16,17,16))
abline(h=1,lty=2)
dev.off()

#recode Diebold mariano using stars
output$m3dm <- stars(output$m3dm)
output$m6dm <- stars(output$m6dm)
output$m12dm <- stars(output$m12dm)
output$m24dm <- stars(output$m24dm)

#round all the numbers in the output dataframe to 3 significant digits
for(i in theseones){
output[,i] <- round(output[,i],3)
}



colnames(output) <- c(" "," ","3 months"," ","6 months"," ","1 year"," ","2 year"," ")
	latextemp <- latex(
		output,
		file=paste(filefolder,"RelativeRMSE.tex",sep=""),
		rowname=NULL,
		caption="Relative Root Mean Squared Error of forecast using different measures of core inflation. The baseline model in rows labelled CPIAUCSL uses a single lag of all items CPI. Rows labelled CPILFESL and SA0L12E are relative RMSE.  The models are trained on pre 2000 data and the forecast is made for post 2000 data. Diebold-Mariano test significance implemented in the forecast R package. Significance Codes: . $<0.1$, * $<.05$, ** $<.01$ .",
		caption.lot="Relative RMSE CPILFESL vs SA0L12E",
		caption.loc="bottom",
		#colheads=FALSE,
		col.just=rep("c",10),
		cgroup=c("Training Set","Core Measure", "Horizon"),
		n.cgroup = c(1,1,8),
		n.rgroup = c(3,3),
		#extracolheads=c(" "," ","1 yr","2 yr","5 yr","10 yr"),
		label="table:RelativeRMSE"
		)
















































##Show that CPILFESL is more correlated with unemployment rate than All items less shelter.
	plot(CPILFESL_full ~ UNRATE_full, type='l')
	plot(SA0L12E_full ~ UNRATE_full , type='l')
		#Note that each is rising in unemployment because the trend in inflation is in both. 

fit <- dynlm(I(CPILFESL_full-SA0L12E_full) ~ UNRATE_full)
subtitle <- paste("red line: ",round(fit$coefficients, 3)[1],"+",round(fit$coefficients, 3)[2],"*unemployment rate , r^2=",round(summary(fit)$r.squared,3), sep="") 
plot(I(CPILFESL_full-SA0L12E_full) ~ UNRATE_full,type='l', sub=subtitle, ylab="excess shelter inflation", xlab="unemployment rate") 
abline(fit, lwd=2, col='red')
	# The difference between the two measures of core inflation is correlated with unemployment. 
	# The difference between CPI less Food and Fuel and CPI less Food Fuel and Shelter is mostly a weighted shelter component. 
	# CPI less Food and Fuel still has this element that is correlated with unemployment inside of it. 

	#This is mostly the weighted shelter component.
	#That is a pretty sharp relation, but with one huge loop in the late 1970s and early 1980s.


plot(I(CPILFESL_full-SA0L12E_full), ylab="excess shelter inflation")
lines(ts(fit$fitted.values, start=c(1968,1), frequency=12 ) , col='blue')
legend('topright', legend=c("data","predicted"), col=c('black','blue'),lty=c(1,1))
abline(h=0,lty=2)

	# plot(I(CPIAUCSL_full-SA0L12E_full) ~ UNRATE_full, type='l') #Still that 1980 loop. So thats the food fuel and shelter components.  
	# plot(I(CPIAUCSL_full-CPILFESL_full) ~ UNRATE_full, type='l') #Huh no 1980 loop.  This is just the weighted food and fuel components.
plot(I(CPIAUCSL_full-SA0L12E_full), type='l', ylab="CPI less CORE", sub="Each series is calculated as CPI minus core.")
lines(I(CPIAUCSL_full-CPILFESL_full), col='red')
legend('topright', legend=c("food, fuel, & shelter","food & fuel"), col=c('black','red'),lty=c(1,1))
abline(v=1973,lty=2) # Yom Kippur war oil shock
abline(v=1978,lty=2) # Iran oil shock
abline(h=0,lty=2)

	#What is it about the 1980 spike? 
		# Before 1985, the shelter component of inflation includes home prices and mortgage interest rates (Lane and Gillingham 1981) . 
		# Home prices grew fastest before 1980 according the All Transaction Home Price Index. 
		# The evolution of the rent of primary residence component of inflation (CUUR0000SEHA) gradually rises throughout the seventies and does not spike like shelter. 
		# So the 1980 spike seems to be the result of rising mortgage interest rates, themselves a function of the federal funds rate.
		# A research series CPI-U-RS that applies rental equivalent methods to data before 1985 and reduces the peak inflation in 1980 from 14 down to 10 percent. ( https://www.bls.gov/cpi/research-series/allitems.pdf )
		#Lane and Gillingham had a similar series (CPI-U-X1, see their Chart 1) that shaved off peak inflation but by about 2 percentage points. 
		# Blinder (table 6 p.556 1980 Brookings Paper The Consumer Price Index and the Measurement of Recent Inflation) reports a difference of 3.1 percentage points between headline and rental equivalent CPI in June 1980. 
		#If we take the CPI-U-RS 4 point difference as a guide then that brings inflation back to the level we would expect based on unemployment. 

	# The other thing that changes in the 1980 spike is that the weight of shelter rises from the around 21% (1963 to 1976) to 31% (1977 to 1981) before reverting to 21% (1982 to 1985). 
		# Holding the weights constant at 20% only reduces the 1980 spike by 0.5 percentage points from the headline numbers.
		# The weights contribute little to the spike in headline inflation.


#Performing the gross correction, we subtract the difference between all items CPI and CPI-U-RS.
#This is the CPI-U-RS, All items, 1977-2017 from https://www.bls.gov/cpi/research-series/home.htm on June 19 2018

cpiURS <- c(100.0,
100.5,101.1,101.8,102.7,103.6,104.5,105.0,105.5,106.1,106.7,107.3,107.8,
108.7,109.7,110.7,111.8,113.0,114.1,115.1,116.0,117.1,117.9,118.5,119.5,
120.8,122.4,123.8,124.7,125.7,126.7,127.5,128.6,129.9,130.7,131.5,132.4,
133.6,135.2,136.3,137.1,137.9,138.7,139.7,140.7,141.8,142.4,142.9,143.4,
144.2,144.7,144.9,145.0,146.1,147.5,148.5,148.8,149.5,150.2,150.5,150.6,
151.0,151.1,151.2,152.4,153.2,153.7,154.3,154.8,155.6,156.0,156.2,156.4,
157.2,158.0,158.3,159.1,159.5,160.0,160.5,161.1,161.8,162.2,162.2,162.4,
162.6,163.2,164.0,164.6,165.3,165.7,166.0,166.4,166.9,167.3,167.9,168.2,
168.7,168.3,167.5,167.1,167.6,168.4,168.4,168.7,169.6,169.7,169.7,169.9,
170.9,171.5,172.3,173.1,173.6,174.3,174.6,175.5,176.4,176.7,176.9,176.7,
177.2,177.5,178.3,179.1,179.7,180.4,181.1,181.8,183.0,183.4,183.6,183.7,
184.5,185.2,186.2,187.4,188.4,188.8,189.3,189.4,190.1,190.9,191.2,191.4,
193.3,194.1,195.2,195.5,195.8,196.8,197.6,199.3,200.9,202.0,202.3,202.3,
203.2,203.4,203.6,203.8,204.4,204.8,205.0,205.5,206.4,206.5,207.0,207.1,
207.5,208.1,208.9,209.3,209.6,210.1,210.4,210.9,211.5,212.1,212.4,212.3,
212.9,213.6,214.3,214.9,215.3,215.5,215.6,216.1,216.3,217.1,217.2,217.0,
217.4,218.0,218.7,219.0,219.2,219.8,220.3,221.1,221.4,221.6,221.8,221.7,
222.5,223.2,223.9,224.6,225.0,225.5,225.6,226.0,226.5,227.0,226.9,226.7,
227.8,228.6,229.8,230.6,231.1,231.3,231.6,231.9,232.7,233.3,233.7,233.7,
234.4,235.1,235.6,235.8,235.8,236.1,236.2,236.7,237.4,237.8,237.8,237.3,
237.8,238.1,238.5,239.0,239.3,239.5,239.7,240.1,240.4,240.9,240.8,240.6,
241.3,241.6,242.3,244.0,244.0,244.1,244.7,245.4,246.5,247.1,247.2,247.2,
248.0,249.4,251.4,251.6,251.8,253.2,253.7,253.8,255.1,255.5,255.7,255.5,
257.2,258.2,258.9,259.8,260.9,261.5,260.7,260.8,261.8,261.0,260.5,259.5,
260.2,261.2,262.6,264.1,264.0,264.2,264.5,265.4,265.8,266.3,266.3,265.7,
266.9,269.0,270.6,269.9,269.5,269.9,270.2,271.2,272.0,271.8,271.0,270.7,
272.1,273.6,275.3,276.2,277.7,278.6,278.3,278.4,278.9,280.4,280.6,279.6,
280.1,281.7,283.9,285.8,285.6,285.7,287.0,288.5,292.0,292.6,290.3,289.0,
291.3,291.9,293.6,296.0,297.4,298.1,298.9,299.6,298.1,296.5,296.0,296.5,
297.4,299.0,301.7,303.6,305.5,306.1,306.0,305.5,306.3,306.9,308.8,308.6,
310.1,311.0,313.7,315.6,318.2,321.5,323.2,321.9,321.4,318.2,312.1,308.8,
310.2,311.7,312.5,313.3,314.2,316.9,316.4,317.1,317.3,317.6,317.8,317.3,
318.3,318.4,319.7,320.3,320.5,320.2,320.3,320.7,320.9,321.3,321.5,322.0,
323.6,325.2,328.3,330.5,332.0,331.7,332.0,332.9,333.4,332.7,332.4,331.6,
333.1,334.6,337.1,338.1,337.7,337.3,336.7,338.6,340.1,340.0,338.4,337.5,
338.6,341.4,342.2,341.9,342.5,343.3,343.5,343.9,344.3,343.4,342.8,342.8,
344.1,345.4,347.6,348.7,350.0,350.7,350.5,349.9,350.2,349.3,347.5,345.6,
344.0,345.5,347.5,348.3,350.0,351.3,351.3,350.8,350.3,350.2,349.4,348.3,
348.8,349.1,350.6,352.3,353.7,354.9,354.3,354.7,355.5,356.0,355.4,355.5,
357.6,358.7,359.0,360.1,360.4,360.7,360.5,361.6,363.5,363.2,363.3,363.1)

cpiURS <- ts(cpiURS, start=c(1977,12), freq=12)
inflRS <- 100*diff(cpiURS,lag=12)/cpiURS

correctionRS <- CPIAUCSL_full-inflRS

	plot(correctionRS)
	abline(h=0,lty=2)
	#This plot shows the extent of the correction of headline down to CPIURS

fit <- dynlm( as.vector(CPILFESL_full-SA0L12E_full-correctionRS) ~ as.vector(window(UNRATE_full, start=c(1978,12), end=c(2017,12) )  ))
subtitle <- paste("blue line: ",round(fit$coefficients, 3)[1],"+",round(fit$coefficients, 3)[2],"*unemployment rate , r^2=",round(summary(fit)$r.squared,3), sep="") 
plot(I(CPILFESL_full-SA0L12E_full) ~ UNRATE_full,type='l', sub=subtitle, ylab="excess shelter inflation", xlab="unemployment rate") 
lines( as.vector(CPILFESL_full-SA0L12E_full-correctionRS) ~ as.vector(window(UNRATE_full, start=c(1978,12), end=c(2017,12) ) ), col='blue')
abline(fit, lwd=2, col='blue')

	#This certainly reduces the loop formed in the 1980s from the spike in housing shown below. 

plot(I(CPILFESL_full-SA0L12E_full))
lines((CPILFESL_full-SA0L12E_full-correctionRS), col='blue')
lines(ts(fit$fitted.values,start=c(1978,12), frequency=12), col='red')
lines(1.442-0.219*UNRATE_full, col='red')
abline(h=0,lty=2)
legend('topright', legend=c('excess shelter inflation','corrected using CPI less CPI-U-RS',paste(round(fit$coefficients, 3)[1],"+",round(fit$coefficients, 3)[2],"*unemployment rate")), col=c('black','blue','red'),lty=c(1,1,1))


### So other than a spike in shelter inflation in 1980, that can be corrected to make it more like the rental equivalence measure, the aggregate shelter component is correlated with unemployment. 
# This makes SA0L12E the better measure of core inflation. 



plot((CPIAUCSL_full-SA0L12E_full)~UNRATE_full, type='l', ylab="food shelter and energy deviation", xlab="unemployment rate")
fit <- dynlm((CPIAUCSL_full-SA0L12E_full)~UNRATE_full)
abline(fit, lwd=2)
summary(fit)
#Note that the r^squared of the headline less core model is better when core includes shelter
#Obviously, this is because the non-core includes a highly correlated component. 
lines(as.vector(CPIAUCSL_full-SA0L12E_full-correctionRS) ~ as.vector(window(UNRATE_full, start=c(1978,12), end=c(2017,12))), col='blue')
fit <- lm(as.vector(CPIAUCSL_full-SA0L12E_full-correctionRS)~ as.vector(window(UNRATE_full, start=c(1978,12), end=c(2017,12)))  )
abline(fit, lwd=2, col='blue')
summary(fit)
# The correction using the RS series improves the model fit (.14 to .24). 
# The slope of excess inflation with respect to unemployment is -0.34. 

# In other words, accounting for the mortgage interest cost spike in 1980 improves the relation between unemployment and excess inflation. 




plot((CPIAUCSL_full-CPILFESL_full)~UNRATE_full, type='l', ylab="food and energy deviation", xlab="unemployment rate")
fit <- dynlm((CPIAUCSL_full-CPILFESL_full)~UNRATE_full)
abline(fit, lwd=2)
summary(fit)
#The rsquared here is small. 
lines(as.vector(CPIAUCSL_full-CPILFESL_full-correctionRS) ~ as.vector(window(UNRATE_full, start=c(1978,12), end=c(2017,12))), col='blue')
fit <- lm(as.vector(CPIAUCSL_full-CPILFESL_full-correctionRS)~ as.vector(window(UNRATE_full, start=c(1978,12), end=c(2017,12)))  )
abline(fit, lwd=2, col='blue')
summary(fit)
#The correction using CPI-U-RS is no great improvement. 
#Deviations of inflation from the standard core is still correlated with unemployment but the slope is -0.16.  


# SA0L12E is a comparable to CPILFESL in predicting future inflation. 
# SA0L12E better excises a component that is correlated with unemployment. 










output <- data.frame(matrix(,nrow=0,ncol=9))
colnames(output) <- c("core","intercept","intercept_se","intercept_pval","unrate","unrate_se","unrate_pval","rsquared","adjusted")

starthere <- c(1978,12)
endhere <- c(2017,12)
for(i in c("SA0L12E_full","CPILFESL_full")){
	core       <- eval(parse(text=paste("window(",i,",start=starthere, end=endhere )",sep="")  ))
	depvar     <- window(CPIAUCSL_full, start=starthere, end=endhere )
	indyvar    <- window(UNRATE_full  , start=starthere, end=endhere )
	correction <- window(correctionRS , start=starthere, end=endhere )

	fit <- dynlm((depvar-core) ~ indyvar)
	subtitle1 <- paste("Unadjusted:",round(summary(fit)$coefficients[2,1],3), stars(summary(fit)$coefficients[2,4])," r^2:",round(summary(fit)$adj.r.squared,3),sep="")
	fit1 <- dynlm((depvar-core-correction) ~ indyvar)
	subtitle2 <- paste("Adjusted:",round(summary(fit1)$coefficients[2,1],3), stars(summary(fit1)$coefficients[2,4])," r^2:",round(summary(fit1)$adj.r.squared,3),sep="")
	if(i=="SA0L12E_full" ){ 
		ylabel <- "All items minus SA0L12E"  
		fname  <- paste(filefolder,"CPIminusSA0L12EvUNRATE.png")
		fname1 <- paste(filefolder,"CPIminusSA0L12EvUNRATE_corrected.png")
		}
	if(i=="CPILFESL_full"){ 
		ylabel <- "All items minus CPILFESL" 
		fname  <- paste(filefolder,"CPIminusCPILFESLvUNRATE.png")
		fname1 <- paste(filefolder,"CPIminusCPILFESLvUNRATE_corrected.png")
		}


#Journal of Macroeconomics author submission guidelines ask for TIFF files! I'll throw in a for loop to handle it.

for(fnameformat in c(".png",".tiff")){

	if(fnameformat==".png" ){ png(fname1)}
	if(fnameformat==".tiff"){
		fname1 <- gsub(".png",".tiff",fname1)
		tiff(fname1)
	}
	par(mar=c(2.6,2.6,.5,.5), mgp=c(1.6,.6,0))  #This command makes the margins smaller
	plot((depvar-core) ~ indyvar ,type='l', 
			#sub=paste(subtitle1, subtitle2,sep="    "), 
			ylim=c(-5,7), ylab=ylabel,xlab="unemployment rate",lwd=2,lty=3)
	abline(fit,lwd=3,lty=3)#col='black',lwd=3)
	lines(as.vector(depvar-core-correction) ~ as.vector(indyvar),type='l',lwd=2) # col='blue',lwd=2)
	abline(fit1, lwd=3)#  col='blue',lwd=3)
	if(i=="CPILFESL_full" ){ 
		legend('topright',legend=c('unadjusted','adjusted for shelter methods'),col=c('black','black'),lty=c(3,1))
		#legend('topright',legend=c('unadjusted','adjusted for shelter methods'),col=c('black','blue'),lty=c(1,1))
		}
	dev.off()
}

	tempdf <- data.frame(matrix(,nrow=2,ncol=dim(output)[2]))
	colnames(tempdf) <- colnames(output)
	tempdf$core <- substr(i,1,8)
	tempdf[1,2:4] <- summary(fit)$coefficients[1,c(1,2,4)]
	tempdf[1,5:7] <- summary(fit)$coefficients[2,c(1,2,4)]
	tempdf[1,8]   <- summary(fit)$adj.r.squared
	tempdf$adjusted[1] <- " "
	tempdf[2,2:4] <- summary(fit1)$coefficients[1,c(1,2,4)]
	tempdf[2,5:7] <- summary(fit1)$coefficients[2,c(1,2,4)]
	tempdf[2,8]   <- summary(fit1)$adj.r.squared
	tempdf$adjusted[2] <- "adjusted for shelter methods"
	output <- merge(output,tempdf,all=TRUE)
	##readline("next?")

	png(fname)
	plot((depvar-core) ~ indyvar ,type='l', sub=subtitle1, ylim=c(-5,7), ylab=ylabel,xlab="unemployment rate")
	abline(fit,col='black',lwd=2)
	dev.off()
}
output$core <- gsub("_","",output$core)
output$intercept_pval <- stars(output$intercept_pval)
output$unrate_pval <- stars(output$unrate_pval)
output$intercept_se <- paste("(",round(output$intercept_se,3),")",sep="")
output$unrate_se    <- paste("(",round(output$unrate_se,3),")",sep="")
output$intercept    <- round(output$intercept,3)
output$unrate       <- round(output$unrate,3)
output$rsquared     <- round(output$rsquared,3)
output <- output[order(output$core,output$adjusted),]


	latextemp <- latex(
		output,
		file=paste(filefolder,"CPIminusCorevUNRATE.tex",sep=""),
		rowname=NULL,
		caption="Regression Estimates contrasting Core. All items inflation minus core measures as a function of the unemployment rate. Data is limited to 1978 M12 to 2017 M12. All estimates are made with the dynlm R package. ",
		caption.lot="Regression Estimates contrasting Core",
		caption.loc="bottom",
		colheads=FALSE,
		col.just=c("c","r","c","l","r","c","l","c","c"),
		cgroup=c("Core Measure", "Intercept","Unemployment","$r^2$","Adjustment"),
		n.cgroup = c(1,3,3,1,1),
		label="table:CPIminusCorevUNRATE"
		)

