#CityArticle R script
#This script follows from CityAnalysis_08.R
#2019_05_02: The data source is now ConsolidatedData_short.csv in order to submit a smaller file (10mb vs 71mb).



BeginLoading <- Sys.time()

CPI_ItemDict <- read.csv("C:/Users/JTS3/Desktop/CityArticle/CityPanel/CPI_ItemDict.csv",stringsAsFactors=FALSE)
	colnames(CPI_ItemDict) <- c("depvar","description")
CityData <- read.csv("C:/Users/JTS3/Desktop/CityArticle/CityPanel/ConsolidatedData_short.csv", stringsAsFactors=FALSE)


#A convenient function for all those asterisks
stars <- function(input){symnum(input, corr = FALSE, cutpoints = c(0,.001,.01,.05, .1, 1), symbols = c("***","**","*","."," "))}
significancecodes <- "Significance codes: *** $p<.001$, ** $p<.01$, * $p<.05$ . $p<.1$"

#This creates a time variable to build a panel around (months since 1980)
CityData$maz <- round((CityData$MetricYear-1980)*12,1)

###############################################################################################
# A Convenience for plotting
###############################################################################################
CityData$color <- as.integer(as.factor(CityData$cmsa))

###############################################################################################
# Load packages
###############################################################################################
library(plm)
library(Hmisc)

###############################################################################################
EndLoading <- Sys.time()
difftime(EndLoading,BeginLoading)


###############################################################################################
# Set the output directory
###############################################################################################

BeginRunning <- Sys.time()
filefolder <- paste("C:/Users/JTS3/Desktop/CityArticle/CityPanel/",gsub(" ","_",gsub(":","",gsub("-","",BeginRunning))),"/",sep="" )
if(!dir.exists(filefolder) ){dir.create(filefolder)}

###############################################################################################
# Some Descriptives for the data section
###############################################################################################

tempdf <- data.frame(sort(unique(CityData$city)))
colnames(tempdf) <- c("city")
nrows <- dim(tempdf)[1]
for(i in c(1:nrows)){ tempdf$cmsa[i] <- unique(CityData$cmsa[CityData$city==tempdf$city[i]]) }
for(i in c(1:nrows)){ tempdf$minyearSA0[i] <- tryCatch( min(CityData$MetricYear[CityData$city==tempdf$city[i] & !is.na(CityData$SA0)] ,na.rm=TRUE), error=function(e) NA  )    }
for(i in c(1:nrows)){ tempdf$maxyearSA0[i] <- tryCatch( max(CityData$MetricYear[CityData$city==tempdf$city[i] & !is.na(CityData$SA0)] ,na.rm=TRUE), error=function(e) NA  )    }
tempdf$minyearSA0 <- paste(substr(tempdf$minyearSA0,1,4),"M",round((tempdf$minyearSA0-as.integer(substr(tempdf$minyearSA0,1,4)))*12 +1,0),sep=""  )
tempdf$maxyearSA0 <- paste(substr(tempdf$maxyearSA0,1,4),"M",round((tempdf$maxyearSA0-as.integer(substr(tempdf$maxyearSA0,1,4)))*12 +1,0),sep=""  )
tempdf$minyearSA0[regexpr("NA",tempdf$minyearSA0)>0] <- "NA"
tempdf$maxyearSA0[regexpr("NA",tempdf$maxyearSA0)>0] <- "NA"
for(i in c(1:nrows)){ tempdf$minyearurate[i] <- tryCatch( min(CityData$MetricYear[CityData$city==tempdf$city[i] & !is.na(CityData$urate)] ,na.rm=TRUE), error=function(e) NA  )    }
for(i in c(1:nrows)){ tempdf$maxyearurate[i] <- tryCatch( max(CityData$MetricYear[CityData$city==tempdf$city[i] & !is.na(CityData$urate)] ,na.rm=TRUE), error=function(e) NA  )    }
tempdf$minyearurate <- paste(substr(tempdf$minyearurate,1,4),"M",round((tempdf$minyearurate-as.integer(substr(tempdf$minyearurate,1,4)))*12 +1,0),sep=""  )
tempdf$maxyearurate <- paste(substr(tempdf$maxyearurate,1,4),"M",round((tempdf$maxyearurate-as.integer(substr(tempdf$maxyearurate,1,4)))*12 +1,0),sep=""  )


	latextemp <- latex(
		tempdf,
		file=paste(filefolder,"BLScoverage.tex",sep=""),
		rowname=NULL,
		caption="Bureau of Labor Statistics Data Availability For All Items Inflation (SA0) And Local Area Unemployment Rates.",
		caption.loc="bottom",
		caption.lot="BLS Data Availability SA0 and LAU",
		colheads=FALSE,
		col.just=c("l","l","c","c","c","c"),
		cgroup=c("city", "CMSA","All Items Inflation","Unemployment"),
		n.cgroup = c(1,1,2,2),
		label="table:BLScoverage"
		#landscape=TRUE
		)






#######################################################################
#     REGRESSIONS 
#######################################################################



#define the panel with its individual and time period indices
panel_data <- pdata.frame(CityData[CityData$MetricYear>=1980,], index=c("city","maz"))

###Question 2: Is there any component of CPI more correlated with unemployment than the other components?
	#Yes, Housing.

	depvars <- c("SA0", "SA0E", "SA0L1E", "SA0L2", "SA0L5", "SA0LE", "SAA", "SAC", "SACL1", "SACL11", "SAD", "SAE", "SAF", "SAF1", "SAF11", "SAF116", "SAG", "SAH", "SAH1", "SAH2", "SAH21", "SAH3", "SAM", "SAN", "SANL1", "SANL11", "SAR", "SAS", "SASL2RS", "SASL5", "SAT", "SAT1", "SEFV", "SEHA", "SEHC", "SEHC01", "SEHF", "SEHF01", "SEHF02", "SETB", "SETB01", "SS47014", "SS47016", "AA0", "SS47015", "SAEC", "SAES", "SAGC", "SAGS", "SAH31", "SATCLTB")
	output <- data.frame(matrix(,nrow=length(depvars),ncol=7))
	colnames(output) <- c("depvar","urate","se","pval","adjrsq","minyear","maxyear")
	output$depvar <- depvars
	for(depvar in depvars){
		fit <- plm(eval(parse(text=paste("panel_data$",depvar,sep=""))) ~ panel_data$urate | lag(panel_data$urate,k=12),data=panel_data,effect="individual" )
		output[output$depvar==depvar,c(2,3,4)]<-round(summary(fit)$coefficients["panel_data$urate",c(1,2,4)],3)
		output[output$depvar==depvar,5] <- round(summary(fit)$r.squared[2],3)
		output[output$depvar==depvar,c("minyear")] <- min(panel_data$MetricYear[!is.na(eval(parse(text=paste("panel_data$",depvar,sep="")))) & !is.na(panel_data$urate)]) 
		output[output$depvar==depvar,c("maxyear")] <- max(panel_data$MetricYear[!is.na(eval(parse(text=paste("panel_data$",depvar,sep="")))) & !is.na(panel_data$urate)])
	}
	output <- merge(output,CPI_ItemDict,all.x=TRUE)
	depvars <- c("SA0","SA0L2","SAA","SAC","SAD","SAE","SAF","SAG","SAH","SAH1","SAH2","SAH3","SAM","SAN","SAR","SAS","SASL2RS","SAT","SETB")
	#"SATCLTB" looks like it has a strong positive correlation until you examine the larger "SAT" category over a longer period.
	output <- output[output$depvar %in% depvars,]
	output <- output[order(output$depvar),c("depvar","description","urate","se","pval","adjrsq","minyear","maxyear")]
		#This table shows that much of the Phillips curve is about Housing. 
		#Housing SAH and Shelter SAH1 has a sizable adjusted r.squared.  
		#To emphasize that it is Shelter, and not oil prices I include SAH3 which has a weak adjusted r. squared. 
		#Services SAS also has a sizable adjusted r.squared until you look at Services Less Shelter SASL2RS which is quite weak. 
	output$pval <- stars(output$pval) #symnum(output$pval, corr = FALSE, cutpoints = c(0,.001,.01,.05, .1, 1), symbols = c("***","**","*","."," "))
	output$se <- paste("(",sprintf("%.3f",output$se),")",sep="")
	output$minyear <- paste(substr(output$minyear,1,4),"M", round((output$minyear - as.integer(substr(output$minyear,1,4)))*12 + 1) ,sep="")
	output$maxyear <- paste(substr(output$maxyear,1,4),"M", round((output$maxyear - as.integer(substr(output$maxyear,1,4)))*12 + 1) ,sep="")
	output$timespan <- paste(output$minyear,"--",output$maxyear,sep="")
		output$description[12] <- "Household furnishings and ops."   #This line exists to make the table neater
	output <- output[,c("depvar","description","urate","se","pval","adjrsq","timespan")]

	latextemp <- latex(
		format.df(output, dec=3,dcolumn=TRUE),
		file=paste(filefolder,"associationHUNT.tex",sep=""),
		rowname=NULL,
		caption=paste("Panel Regressions Of All Component Inflation Rates On The Unemployment Rate.",significancecodes),
		caption.loc="bottom",
		caption.lot="All Component Inflation Rates",
		colheads=FALSE,
		col.just=c("l@{ }","l","r@{ }","c@{}","l@{}","c","r"),
		cgroup=c("Inflation Component", "Unemployment","Adjusted $r^2$", "Time Span"),
		n.cgroup = c(2,3,1,1),
		size="small",
		label="table:associationHUNT"
		)




##Kiley Plots
########################


	#Replicate Kiley's result with All Items Inflation and produce a plot
	fit0a <- plm(panel_data$SA0 ~ panel_data$urate,data=panel_data,effect="individual" )
	fit0b <- plm(panel_data$SA0 ~ panel_data$urate,data=panel_data,effect="twoway" )
	summary(fit0a)
	summary(fit0b)

	fname <- paste(filefolder,"KileySA0.png",sep="")
	png(fname)
	par(mar=c(2.6,2.6,.5,.5), mgp=c(1.6,.6,0))  #This command makes the margins smaller
	plot(panel_data$SA0 ~ panel_data$urate, ylab="All items inflation", 
		xlab="",#xlab="Unemployment rate",
		xlim=c(0,20),ylim=c(-5,12))
	fit0c <- pvcm(panel_data$SA0 ~ panel_data$urate,data=panel_data)$coefficients    #THESE ARE THE INDIVIDUAL CITY REGRESSION  COEFFS
	for(i in c(1:dim(fit0c)[1])){abline(unlist(fit0c[i,]),lty=3 )}
	abline(unlist(fit0c["A422",]),lty=2 ,lwd=2,col='red')
	abline(unlist(fit0c["A318",]),lty=2 ,lwd=2,col='yellow')
	abline(unlist(fit0c["A208",]),lty=2 ,lwd=2,col='blue')
	points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="San Francisco-Oakland-San Jose, CA", pch=16, col='red')
	points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="Houston-Galveston-Brazoria, TX", pch=16, col='yellow')
	#points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="Atlanta, GA", pch=16, col='pink')
	points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="Detroit-Ann Arbor-Flint, MI", pch=16, col='blue')
	abline(mean(fixef(fit0b,effect="individual")),coefficients(fit0b), lwd=3)
	legend('bottomleft',legend=c("San Francisco-Oakland-San Jose, CA","Houston-Galveston-Brazoria, TX","Detroit-Ann Arbor-Flint, MI"),col=c("red","yellow","blue"),pch=c(16,16,16))
	dev.off()

	#Show that Kiley's result is driven by SAH1
	fit1a <- plm(panel_data$SAH1 ~ panel_data$urate, data=panel_data,effect="individual" )
	fit1b <- plm(panel_data$SAH1 ~ panel_data$urate, data=panel_data,effect="twoway" )
	summary(fit1a)
	summary(fit1b)

	fname <- paste(filefolder,"KileySAH1.png",sep="")
	png(fname)
	par(mar=c(2.6,2.6,.5,.5), mgp=c(1.6,.6,0))  #This command makes the margins smaller
	plot(panel_data$SAH1 ~ panel_data$urate, ylab="Shelter inflation", 
		xlab="",#xlab="Unemployment rate",
		xlim=c(0,20),ylim=c(-5,12))
	fit1c <- pvcm(panel_data$SAH1 ~ panel_data$urate,data=panel_data)$coefficients    #THESE ARE THE INDIVIDUAL CITY REGRESSION  COEFFS
	for(i in c(1:dim(fit1c)[1])){abline(unlist(fit1c[i,]),lty=3 )}
	abline(unlist(fit1c["A422",]),lty=2 ,lwd=2,col='red')
	abline(unlist(fit1c["A318",]),lty=2 ,lwd=2,col='yellow')
	abline(unlist(fit1c["A208",]),lty=2 ,lwd=2,col='blue')
	points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="San Francisco-Oakland-San Jose, CA", pch=16, col='red')
	points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="Houston-Galveston-Brazoria, TX", pch=16, col='yellow')
	#points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="Atlanta, GA", pch=16, col='pink')
	points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="Detroit-Ann Arbor-Flint, MI", pch=16, col='blue')
	abline(mean(fixef(fit1b,effect="individual")),coefficients(fit1b), lwd=3)
	#legend('bottomleft',legend=c("San Francisco","Houston","Detroit"),col=c("red","yellow","blue"),pch=c(16,16,16))
	dev.off()

	fit2a <- plm(panel_data$SA0L2 ~ panel_data$urate, data=panel_data,effect="individual" )
	fit2b <- plm(panel_data$SA0L2 ~ panel_data$urate, data=panel_data,effect="twoway" )
	summary(fit2a)
	summary(fit2b)

	#This shows that the Kiley result does not clearly show up if you take out Shelter Inflation
	fname <- paste(filefolder,"KileySA0L2.png",sep="")
	png(fname)
	par(mar=c(2.6,2.6,.5,.5), mgp=c(1.6,.6,0))  #This command makes the margins smaller
	plot(panel_data$SA0L2 ~ panel_data$urate, ylab="All items less Shelter inflation", 
		xlab="Unemployment rate",
		xlim=c(0,20),ylim=c(-5,12))
	fit2c <- pvcm(panel_data$SA0L2 ~ panel_data$urate,data=panel_data)$coefficients    #THESE ARE THE INDIVIDUAL CITY REGRESSION  COEFFS
	for(i in c(1:dim(fit2c)[1])){abline(unlist(fit2c[i,]),lty=3 )}
	abline(unlist(fit2c["A422",]),lty=2 ,lwd=2,col='red')
	abline(unlist(fit2c["A318",]),lty=2 ,lwd=2,col='yellow')
	abline(unlist(fit2c["A208",]),lty=2 ,lwd=2,col='blue')
	points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="San Francisco-Oakland-San Jose, CA", pch=16, col='red')
	points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="Houston-Galveston-Brazoria, TX", pch=16, col='yellow')
	#points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="Atlanta, GA", pch=16, col='pink')
	points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="Detroit-Ann Arbor-Flint, MI", pch=16, col='blue')
	abline(mean(fixef(fit2b,effect="individual")),coefficients(fit2b), lwd=3)
	#legend('bottomleft',legend=c("San Francisco","Houston","Detroit"),col=c("red","yellow","blue"),pch=c(16,16,16))
	dev.off()

	##Not shown here is that Rent of Primary Residence SEHA and the imputed variable Owners Equivalent Rent SEHC have a positive adjusted r-squared and significant model F-statistic 




	##Comboplot
for(fnameformat in c("KileyComboPlot.png","KileyComboPlot.tiff") ){
	fname <- paste(filefolder,fnameformat,sep="")
	if(fnameformat=="KileyComboPlot.png"){png(fname,width=1100)}
	if(fnameformat=="KileyComboPlot.tiff"){tiff(fname,width=1100)}
	par(mar=c(2.6,3.1,.5,.5), mgp=c(1.6,.6,0),mfrow=c(1,3))  #This command makes the margins smaller
	#SA0
	plot(panel_data$SA0 ~ panel_data$urate, ylab="All items inflation", 
		xlab="",#xlab="Unemployment rate",
		xlim=c(0,20),ylim=c(-5,12),cex.lab=2)
	fit0c <- pvcm(panel_data$SA0 ~ panel_data$urate,data=panel_data)$coefficients    #THESE ARE THE INDIVIDUAL CITY REGRESSION  COEFFS
	for(i in c(1:dim(fit0c)[1])){abline(unlist(fit0c[i,]),lty=3 )}
	abline(unlist(fit0c["A422",]),lty=2 ,lwd=2,col='red')
	abline(unlist(fit0c["A318",]),lty=2 ,lwd=2,col='yellow')
	abline(unlist(fit0c["A208",]),lty=2 ,lwd=2,col='blue')
	points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="San Francisco-Oakland-San Jose, CA", pch=16, col='red')
	points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="Houston-Galveston-Brazoria, TX", pch=16, col='yellow')
	#points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="Atlanta, GA", pch=16, col='pink')
	points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="Detroit-Ann Arbor-Flint, MI", pch=16, col='blue')
	abline(mean(fixef(fit0b,effect="individual")),coefficients(fit0b), lwd=3)
	legend('topleft',legend=c("San Francisco-Oakland-San Jose, CA","Houston-Galveston-Brazoria, TX","Detroit-Ann Arbor-Flint, MI"),col=c("red","yellow","blue"),pch=c(16,16,16),cex=2)
	#SA0L2
	plot(panel_data$SA0L2 ~ panel_data$urate, ylab="All items less Shelter inflation", 
		xlab="Unemployment rate",
		xlim=c(0,20),ylim=c(-5,12),cex.lab=2)
	fit2c <- pvcm(panel_data$SA0L2 ~ panel_data$urate,data=panel_data)$coefficients    #THESE ARE THE INDIVIDUAL CITY REGRESSION  COEFFS
	for(i in c(1:dim(fit2c)[1])){abline(unlist(fit2c[i,]),lty=3 )}
	abline(unlist(fit2c["A422",]),lty=2 ,lwd=2,col='red')
	abline(unlist(fit2c["A318",]),lty=2 ,lwd=2,col='yellow')
	abline(unlist(fit2c["A208",]),lty=2 ,lwd=2,col='blue')
	points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="San Francisco-Oakland-San Jose, CA", pch=16, col='red')
	points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="Houston-Galveston-Brazoria, TX", pch=16, col='yellow')
	#points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="Atlanta, GA", pch=16, col='pink')
	points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="Detroit-Ann Arbor-Flint, MI", pch=16, col='blue')
	abline(mean(fixef(fit2b,effect="individual")),coefficients(fit2b), lwd=3)
	#SAH1
	plot(panel_data$SAH1 ~ panel_data$urate, ylab="Shelter inflation", 
		xlab="",#xlab="Unemployment rate",
		xlim=c(0,20),ylim=c(-5,12),cex.lab=2)
	fit1c <- pvcm(panel_data$SAH1 ~ panel_data$urate,data=panel_data)$coefficients    #THESE ARE THE INDIVIDUAL CITY REGRESSION  COEFFS
	for(i in c(1:dim(fit1c)[1])){abline(unlist(fit1c[i,]),lty=3 )}
	abline(unlist(fit1c["A422",]),lty=2 ,lwd=2,col='red')
	abline(unlist(fit1c["A318",]),lty=2 ,lwd=2,col='yellow')
	abline(unlist(fit1c["A208",]),lty=2 ,lwd=2,col='blue')
	points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="San Francisco-Oakland-San Jose, CA", pch=16, col='red')
	points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="Houston-Galveston-Brazoria, TX", pch=16, col='yellow')
	#points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="Atlanta, GA", pch=16, col='pink')
	points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="Detroit-Ann Arbor-Flint, MI", pch=16, col='blue')
	abline(mean(fixef(fit1b,effect="individual")),coefficients(fit1b), lwd=3)
	#legend('bottomleft',legend=c("San Francisco","Houston","Detroit"),col=c("red","yellow","blue"),pch=c(16,16,16))
	dev.off()
}



	##Comboplot
	fname <- paste(filefolder,"KileyComboPlot_BW.png",sep="")
	png(fname,width=1100)
	par(mar=c(2.6,3.1,.5,.5), mgp=c(1.6,.6,0),mfrow=c(1,3))  #This command makes the margins smaller
	#SA0
	plot(panel_data$SA0 ~ panel_data$urate, ylab="All items inflation", 
		xlab="",#xlab="Unemployment rate",
		xlim=c(0,20),ylim=c(-5,12),cex.lab=2,cex=.1)
	fit0c <- pvcm(panel_data$SA0 ~ panel_data$urate,data=panel_data)$coefficients    #THESE ARE THE INDIVIDUAL CITY REGRESSION  COEFFS
	for(i in c(1:dim(fit0c)[1])){abline(unlist(fit0c[i,]),lty=3 )}
	abline(unlist(fit0c["A422",]),lty=2 ,lwd=2,col='red'   )
	abline(unlist(fit0c["A318",]),lty=2 ,lwd=2,col='yellow')
	abline(unlist(fit0c["A208",]),lty=2 ,lwd=2,col='blue'  )
	points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="San Francisco-Oakland-San Jose, CA", pch=1, cex=2)
	points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="Houston-Galveston-Brazoria, TX", pch=2, cex=2)
	#points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="Atlanta, GA", pch=16, col='pink')
	points(panel_data$SA0 ~ panel_data$urate, subset=panel_data$cmsa=="Detroit-Ann Arbor-Flint, MI", pch=0, cex=2)
	abline(mean(fixef(fit0b,effect="individual")),coefficients(fit0b), lwd=3)
	legend('topleft',legend=c("San Francisco-Oakland-San Jose, CA","Houston-Galveston-Brazoria, TX","Detroit-Ann Arbor-Flint, MI"),col=c("red","yellow","blue"),pch=c(16,16,16),cex=2)
	#SA0L2
	plot(panel_data$SA0L2 ~ panel_data$urate, ylab="All items less Shelter inflation", 
		xlab="Unemployment rate",
		xlim=c(0,20),ylim=c(-5,12),cex.lab=2,cex=.1)
	fit2c <- pvcm(panel_data$SA0L2 ~ panel_data$urate,data=panel_data)$coefficients    #THESE ARE THE INDIVIDUAL CITY REGRESSION  COEFFS
	for(i in c(1:dim(fit2c)[1])){abline(unlist(fit2c[i,]),lty=3 )}
	abline(unlist(fit2c["A422",]),lty=2 ,lwd=2,col='red')
	abline(unlist(fit2c["A318",]),lty=2 ,lwd=2,col='yellow')
	abline(unlist(fit2c["A208",]),lty=2 ,lwd=2,col='blue')
	points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="San Francisco-Oakland-San Jose, CA", pch=1, cex=2)
	points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="Houston-Galveston-Brazoria, TX", pch=2, cex=2)
	#points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="Atlanta, GA", pch=16, col='pink')
	points(panel_data$SA0L2 ~ panel_data$urate, subset=panel_data$cmsa=="Detroit-Ann Arbor-Flint, MI", pch=0, cex=2)
	abline(mean(fixef(fit2b,effect="individual")),coefficients(fit2b), lwd=3)
	#SAH1
	plot(panel_data$SAH1 ~ panel_data$urate, ylab="Shelter inflation", 
		xlab="",#xlab="Unemployment rate",
		xlim=c(0,20),ylim=c(-5,12),cex.lab=2,cex=.1)
	fit1c <- pvcm(panel_data$SAH1 ~ panel_data$urate,data=panel_data)$coefficients    #THESE ARE THE INDIVIDUAL CITY REGRESSION  COEFFS
	for(i in c(1:dim(fit1c)[1])){abline(unlist(fit1c[i,]),lty=3 )}
	abline(unlist(fit1c["A422",]),lty=2 ,lwd=2,col='red')
	abline(unlist(fit1c["A318",]),lty=2 ,lwd=2,col='yellow')
	abline(unlist(fit1c["A208",]),lty=2 ,lwd=2,col='blue')
	points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="San Francisco-Oakland-San Jose, CA", pch=1, cex=2)
	points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="Houston-Galveston-Brazoria, TX", pch=2, cex=2)
	#points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="Atlanta, GA", pch=16, col='pink')
	points(panel_data$SAH1 ~ panel_data$urate, subset=panel_data$cmsa=="Detroit-Ann Arbor-Flint, MI", pch=0, cex=2)
	abline(mean(fixef(fit1b,effect="individual")),coefficients(fit1b), lwd=3)
	#legend('bottomleft',legend=c("San Francisco","Houston","Detroit"),col=c("red","yellow","blue"),pch=c(16,16,16))
	dev.off()

















	#Write all these results to file 
	output <- data.frame("individual","SA0",rownames(summary(fit0a)$coefficients),summary(fit0a)$coefficients,t(summary(fit0a)$r.squared),summary(fit0a)$fstatistic[4])
	colnames(output) <- c("effect","depvar","indyvar","Estimate","StdError","Tvalue","Pvalue","rsq","adjrsq","ModelPvalue")
	tempdf <- data.frame("twoway","SA0",rownames(summary(fit0b)$coefficients),summary(fit0b)$coefficients,t(summary(fit0b)$r.squared),summary(fit0b)$fstatistic[4])
	colnames(tempdf) <- c("effect","depvar","indyvar","Estimate","StdError","Tvalue","Pvalue","rsq","adjrsq","ModelPvalue")
	output <- rbind(output,tempdf)
	tempdf <- data.frame("individual","SAH1",rownames(summary(fit1a)$coefficients),summary(fit1a)$coefficients,t(summary(fit1a)$r.squared),summary(fit1a)$fstatistic[4])
	colnames(tempdf) <- c("effect","depvar","indyvar","Estimate","StdError","Tvalue","Pvalue","rsq","adjrsq","ModelPvalue")
	output <- rbind(output,tempdf)
	tempdf <- data.frame("twoway","SAH1",rownames(summary(fit1b)$coefficients),summary(fit1b)$coefficients,t(summary(fit1b)$r.squared),summary(fit1b)$fstatistic[4])
	colnames(tempdf) <- c("effect","depvar","indyvar","Estimate","StdError","Tvalue","Pvalue","rsq","adjrsq","ModelPvalue")
	output <- rbind(output,tempdf)
	tempdf <- data.frame("individual","SA0L2",rownames(summary(fit2a)$coefficients),summary(fit2a)$coefficients,t(summary(fit2a)$r.squared),summary(fit2a)$fstatistic[4])
	colnames(tempdf) <- c("effect","depvar","indyvar","Estimate","StdError","Tvalue","Pvalue","rsq","adjrsq","ModelPvalue")
	output <- rbind(output,tempdf)
	tempdf <- data.frame("twoway","SA0L2",rownames(summary(fit2b)$coefficients),summary(fit2b)$coefficients,t(summary(fit2b)$r.squared),summary(fit2b)$fstatistic[4])
	colnames(tempdf) <- c("effect","depvar","indyvar","Estimate","StdError","Tvalue","Pvalue","rsq","adjrsq","ModelPvalue")
	output <- rbind(output,tempdf)
	rownames(output) <- c(1:6)
	#fname <- paste(filefolder,"Kiley.csv",sep="")
	#write.csv(output,fname,row.names=FALSE)

	output$Pvalue <-   stars(output$Pvalue) #symnum(output$Pvalue, corr = FALSE, cutpoints = c(0,.001,.01,.05, .1, 1), symbols = c("***","**","*","."," "))
	output$ModelPvalue <-   stars(output$ModelPvalue) #symnum(output$ModelPvalue, corr = FALSE, cutpoints = c(0,.001,.01,.05, .1, 1), symbols = c("***","**","*","."," "))
	output$StdError <- paste("(",sprintf("%.3f",output$StdError),")",sep="")
	output <- merge(output,CPI_ItemDict,all.x=TRUE) #drop in descriptions
	output$Estimate <- round(output$Estimate,3)
	output$adjrsq <- round(output$adjrsq,3)
	output <- output[,c("depvar","description","Estimate","StdError","Pvalue","adjrsq","effect")]

	latextemp <- latex(
		output,
		file=paste(filefolder,"Kiley.tex",sep=""),
		rowname=NULL,
		caption=paste("Panel Regressions Of All items (SA0), Shelter (SAH1), and All items less Shelter (SA0L2) Component Inflation Rates On The Unemployment Rate.",significancecodes),
		caption.loc="bottom",
		caption.lot="Panel Regressions Of SA0, SAH1, SA0L2",
		colheads=FALSE,
		col.just=c("l","l","r@{ }","c@{}","l@{}","c","c"),
		cgroup=c("Inflation Component", "Unemployment Rate","Adjusted $r^2$", "Fixed Effects"),
		n.cgroup = c(2,3,1,1),
		label="table:Kiley"
		)




#------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
#------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

	##STEP 0: This is just a pooling test; does the same slope apply to each city?

	output <- data.frame(matrix(,nrow=0,ncol=6))
	colnames(output) <- c("depvar","statistic","p.value","df1","df2","alternative")
	for(depvar in c("SA0","SAH1")){
		tempdf <- data.frame(matrix(,nrow=1,ncol=dim(output)[2] ))
		colnames(tempdf) <- colnames(output)
		fitpool <- pooltest(eval(parse(text=paste("panel_data$",depvar,sep=""))) ~ panel_data$urate, data=panel_data,effect="individual")
		tempdf$depvar       <- depvar 
		tempdf$statistic    <- fitpool$statistic
		tempdf$p.value      <- fitpool$p.value
		tempdf$df1          <- fitpool$parameter[1]
		tempdf$df2          <- fitpool$parameter[2]
		tempdf$alternative  <- fitpool$alternative
		output <- merge(output,tempdf,all=TRUE)
	}
	output$p.value <- stars(output$p.value) # symnum(output$p.value, corr = FALSE, cutpoints = c(0,.001,.01,.05, .1, 1), symbols = c("***","**","*","."," "))

	output$statistic <- round(output$statistic,3)
	output$alternative[output$alternative=="unstability"] <- "instability"

	latextemp <- latex(
		output,
		file=paste(filefolder,"KileyPoolTests.tex",sep=""),
		rowname=NULL,
		caption=paste("Pooling Tests for Panel Regressions Of SA0 and SAH1 Component Inflation Rates On The Unemployment Rate.",significancecodes),
		caption.lot="Pooling Tests for SA0 and SAH1",
		caption.loc="bottom",
		colheads=FALSE,
		col.just=c("l","r","l","c","c","r"),
		cgroup=c("Inflation Component", "F-statistic","Degrees of Freedom", "Verdict"),
		n.cgroup = c(1,2,2,1),
		label="table:KileyPoolTests"
		)
		#This test supports the alternative hypothesis that there are cities that do not have the same slope. 
		##The obvious example is Pittsburgh, but we need to closely examine variation in the slopes. 



	#STEP 1: Show that the slopes from the pvcm of SAH1 on unrate are correlated with Saiz' undevelopable land measure and correlated with the extent to which the housing stock grew in the mid 2000s.
	## The Phillips curve slope from Blanchard and Kiyotaki comes from the elasticity of marginal cost with respect to output and the scope for substitution between goods along with the number of firms and households. 
	## The effect of land constraints on the slope should then affect the scope for substitution between goods.
		## As a measure of land constraints, I use Saiz' measure of undevelopable land (the share of the area within 50 kilometers of the city center that is not underwater or on a slope greater than 15 percent). 
		## I also include the rate of housing stock growth between 2000 and 2010. A city with faster housing stock growth over a decade must have been able to expand housing supply faster. I grant that this has demand mixed in, but over a ten year time period one would expect supply conditions to matter more.
		## I include winter average low temperatures to control for differing demand. There has been a noted general movement of people to the south in favor of milder winters.


	


		fit <- pvcm(panel_data$SAH1 ~ panel_data$urate,data=panel_data,effect="individual")	
		tempdf <- fit$coefficients
		colnames(tempdf)[1:2] <- c("interceptEST","urateEST")
		tempdf1 <- fit$std.error
		colnames(tempdf1)[1:2] <- c("interceptSE","urateSE")
		tempdf$city <- rownames(tempdf)
		tempdf1$city <- rownames(tempdf1)
		tempdf <- merge(tempdf,tempdf1,all=TRUE)
			#marginal cost sensitivity of unemployment
			fit <- pvcm(panel_data$avg_wkly_wage_pctchange_10_0 ~ panel_data$urate,data=panel_data,effect="individual")	
			tempdf1 <- fit$coefficients
			colnames(tempdf1) <- c("intercept_WAGE","KAPPA_WAGE")
			tempdf1$city <- rownames(tempdf1)
			tempdf1 <- tempdf1[,c("city","KAPPA_WAGE")]
			tempdf <- merge(tempdf,tempdf1,all.x=TRUE)
		rm(tempdf1)
		tempdf$cmsa <- rep(NA,dim(tempdf)[1])
		for(i in tempdf$city){ tempdf$cmsa[tempdf$city==i]<-unique(as.character(panel_data$cmsa[panel_data$city==i])) }
		for(i in tempdf$city){ tempdf$SaizUndevelopable[tempdf$city==i]<-unique(panel_data$SaizUndevelopable[panel_data$city==i]) }
		for(i in tempdf$city){ tempdf$JanAvgLow[tempdf$city==i]<-unique(panel_data$JanAvgLow[panel_data$city==i]) }
		for(i in tempdf$city){ tempdf$HousingStock1990[tempdf$city==i]<-na.omit(panel_data$HousingStock[panel_data$city==i & panel_data$MetricYear==1990]) }
		for(i in tempdf$city){ tempdf$HousingStock2000[tempdf$city==i]<-panel_data$HousingStock[panel_data$city==i & panel_data$MetricYear==2000] }
		for(i in tempdf$city){ tempdf$HousingStock2010[tempdf$city==i]<-panel_data$HousingStock[panel_data$city==i & panel_data$MetricYear==2010] }
		tempdf$HousingStock_pctchange <- 100*(log(tempdf$HousingStock2010/tempdf$HousingStock2000)/(10))
		tempdf$HousingStock_pctchange_1990 <- 100*(log(tempdf$HousingStock2000/tempdf$HousingStock1990)/(2000-1990))

		tempdf$cmsa2 <- substr(tempdf$cmsa,1,regexpr("-",tempdf$cmsa)-1)
		tempdf$cmsa2[tempdf$cmsa2==""] <- tempdf$cmsa[tempdf$cmsa2==""]

		#output <- tempdf[,c("cmsa2","urateEST","urateSE","SaizUndevelopable","HousingStock_pctchange","HousingStock_pctchange_1990")]
		output <- tempdf[,c("cmsa2","urateEST","urateSE","SaizUndevelopable","HousingStock_pctchange","HousingStock_pctchange_1990")]
		output$urateEST <- paste(sprintf("%.3f",output$urateEST)," ","(",sprintf("%.3f",output$urateSE),")",sep="")
		output <- output[,c("cmsa2","urateEST","SaizUndevelopable","HousingStock_pctchange","HousingStock_pctchange_1990")]
		output <- output[order(output$HousingStock_pctchange),]

		print(cor.test(output$HousingStock_pctchange,output$HousingStock_pctchange_1990))

	latextemp <- latex(
		format.df(output, dec=3,dcolumn=TRUE),
		file=paste(filefolder,"KileyMSAvSaiz.tex",sep=""),
		rowname=NULL,
		caption=paste("CMSA Specific Regression Coefficients for Shelter Inflation Rates On The Unemployment Rate. 
				Housing Growth is annual average growth rate of aggregated county Census figures: $10*log(Y_{t+10}/Y_{t})$. 
				Undevelopable Land is expressed as a percent of the 50 km area around the city center."),
		caption.lot="CMSA Specific Regression Coefficients of SAH1",
		caption.loc="bottom",
		#colheads=FALSE,
		#col.just=c("l","r@{ }","l","c","c","c"),
		#cgroup=c("CMSA", "Unemployment","Undevelopable Land", "Housing Growth 2000--2010","Housing Growth 1990--2000"),
		#n.cgroup = c(1,2,1,1,1),
		col.just=c("c","c","c","c","c"),
		colheads = c("CMSA", "Unemployment","Undevelopable", "Housing Growth","Housing Growth"),
		extracolheads=c("short name","Rate","Land","2000--2010","1990--2000"),
		extracolsize="normalsize",
		label="table:KileyMSAvSaiz"
		)


for(fnameformat in c("KileyMSAvSaiz.png","KileyMSAvSaiz.tiff")){
		fname <- paste(filefolder,fnameformat,sep="")
		if(fnameformat=="KileyMSAvSaiz.png"){png(fname, width=750, height=250)}
		if(fnameformat=="KileyMSAvSaiz.tiff"){tiff(fname, width=750, height=250)}
		par(mar=c(2.6,2.6,.5,.5), mgp=c(1.6,.6,0))
		plot(tempdf$urateEST ~ tempdf$SaizUndevelopable,pch="" , 
			#sub="Black line is not significant. Red line is significant at 0.05 (excludes Pittsburgh, slope -.005).", 
			ylab="Unemployment Rate Coefficient",#ylab="Unemployment Rate Coefficient (vertical dashes \U00B1 1.96 standard errors)",
			xlab="Undevelopable Land Percent")
		arrows(x0=tempdf$SaizUndevelopable,x1=tempdf$SaizUndevelopable, y0=(tempdf$urateEST-1.96*tempdf$urateSE),y1=(tempdf$urateEST+1.96*tempdf$urateSE),code=0,lty=2)
			fit_saiz <-  lm(tempdf$urateEST ~ tempdf$SaizUndevelopable, weights=tempdf$urateSE^{-1})
			#abline(coefficients(fit_saiz))
			abline(h=0,lty=3)
			#summary(fit_saiz)
			fit_saiz <-  lm(tempdf$urateEST ~ tempdf$SaizUndevelopable, subset=tempdf$cmsa!="Pittsburgh, PA", weights=tempdf$urateSE^{-1})
			abline(coefficients(fit_saiz))
			#summary(fit_saiz)
		text(tempdf$urateEST ~ tempdf$SaizUndevelopable,labels=tempdf$cmsa2,cex=.7)
		dev.off()
	}
	##Only if we EXCLUDE Pittsburgh do we see a significant negative association between the slope of the SAH1 Phillips curve and Saiz' measure of undevelopable land. 
	#A greater share of undevelopable land is associated with a sharper trade off between unemployment and shelter inflation. 
	#The notion here is that a lower unemployment rate will raise rent prices faster in cities with more constrained land.  

output <- data.frame(matrix(,nrow=2,ncol=3))
colnames(output) <- c("Intercept","Saiz","adjrsq")
output[1:2,"Intercept"] <- summary(fit_saiz)$coefficients["(Intercept)",1:2]
output[1:2,"Saiz"] <- summary(fit_saiz)$coefficients["tempdf$SaizUndevelopable",1:2]
output[1,"adjrsq"] <- summary(fit_saiz)$adj.r.squared
output <- round(output,3)
#recode as character string
output[1,] <- paste("$",output[1,],"$",sep="")
output[2,] <- paste("$(",output[2,],")$",sep="")
output[2,3] <- ""



	latextemp <- latex(
		format.df(output, dec=3,dcolumn=TRUE),
		file=paste(filefolder,"KileyMSAvSaizRegression.tex",sep=""),
		rowname=NULL,
		caption=paste("Regression of Shelter Inflation Phillips coefficient on the Undevelopable Land Share. "),
		caption.lot="Regression of SAH1 on Undevelopable Land",
		caption.loc="bottom",
		col.just=c("c","c","c"),
		colheads = c("Intercept", "Undevelopable Land Share", "adj. $r^2$"),
		label="table:KileyMSAvSaiz"
		)
